aboutsummaryrefslogtreecommitdiff
path: root/src/wallet/wallet2.h
diff options
context:
space:
mode:
authorbinaryFate <binaryfate@users.noreply.github.com>2017-10-16 15:13:23 +0200
committerbinaryFate <binaryfate@users.noreply.github.com>2017-10-16 15:14:09 +0200
commitb2d416f211d548b46808988fb19520c0a570b5a8 (patch)
tree49b2a6df6dcca9094538ffbe6b5b7df5d16c7823 /src/wallet/wallet2.h
parentMerge pull request #2601 (diff)
downloadmonero-b2d416f211d548b46808988fb19520c0a570b5a8.tar.xz
Distinguish "not enough money" and "not enough unlocked money"
Fix #1530
Diffstat (limited to '')
-rw-r--r--src/wallet/wallet2.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/wallet/wallet2.h b/src/wallet/wallet2.h
index 26680c3da..55346cf49 100644
--- a/src/wallet/wallet2.h
+++ b/src/wallet/wallet2.h
@@ -1249,10 +1249,10 @@ namespace tools
}
// randomly select inputs for transaction
// throw if requested send amount is greater than amount available to send
std::list<size_t> selected_transfers;
uint64_t found_money = select_transfers(needed_money, unused_transfers_indices, selected_transfers, trusted_daemon);
- THROW_WALLET_EXCEPTION_IF(found_money < needed_money, error::not_enough_money, found_money, needed_money - fee, fee);
+ THROW_WALLET_EXCEPTION_IF(found_money < needed_money, error::not_enough_unlocked_money, found_money, needed_money - fee, fee);
uint32_t subaddr_account = m_transfers[*selected_transfers.begin()].m_subaddr_index.major;
for (auto i = ++selected_transfers.begin(); i != selected_transfers.end(); ++i)
@@ -1249,10 +1249,10 @@ namespace tools
}
// randomly select inputs for transaction
- // throw if requested send amount is greater than amount available to send
+ // throw if requested send amount is greater than (unlocked) amount available to send
std::list<size_t> selected_transfers;
uint64_t found_money = select_transfers(needed_money, unused_transfers_indices, selected_transfers, trusted_daemon);